@@ -1,7 +1,7 @@
 use linya::{Bar, Progress};
 use rand::Rng;
 use rayon::prelude::*;
-use std::sync::{Arc, Mutex};
+use std::sync::Mutex;
 use std::time::Duration;
 
 const BAR_MAX: usize = 1234;
@@ -11,16 +11,16 @@ fn main() {
 
     // `Progress` on its own can't be passed between threads, so we wrap it in
     // the usual sharing types.
-    let progress = Arc::new(Mutex::new(Progress::new()));
+    let progress = Mutex::new(Progress::new());
 
     // `for_each_with` and similar Rayon functions let us pass some `Clone`able
-    // value to each concurrent operation. In this case, it's our Arc-wrapped
+    // value to each concurrent operation. In this case, it's our Mutex-wrapped
     // progress bar coordinator.
-    (0..10).into_par_iter().for_each_with(progress, |p, n| {
+    (0..10).into_par_iter().for_each(|n| {
         // Create a new bar handle. This itself is not a progress bar type as
         // found in similar libraries! Notice below that the increment/draw
         // calls are done on the parent `Progress` type, not this `Bar`.
-        let bar: Bar = p
+        let bar: Bar = progress
             .lock()
             .unwrap()
             .bar(BAR_MAX, format!("Downloading #{}", n));
@@ -31,7 +31,7 @@ fn main() {
         for n in 0..=BAR_MAX {
             // Only draws the line of the specified `Bar` without wasting
             // resources on the others.
-            p.lock().unwrap().set_and_draw(&bar, n);
+            progress.lock().unwrap().set_and_draw(&bar, n);
 
             std::thread::sleep(Duration::from_millis(wait));
         }
